<?php
/**
 * @package     Joomla.Site
 * @subpackage  Templates.jcscoutingtc4
 *
 * @copyright   (C) 2022 Reddie
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * This is a heavily stripped down/modified version of the default Cassiopeia template, designed to build new templates off of.
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;

/** @var Joomla\CMS\Document\HtmlDocument $this */

$app = Factory::getApplication();
$wa  = $this->getWebAssetManager();

// Add Favicon from images folder
$this->addHeadLink(HTMLHelper::_('image', 'favicon.ico', '', [], true, 1), 'icon', 'rel', ['type' => 'image/x-icon']);


// Detecting Active Variables
$option   = $app->input->getCmd('option', '');
$view     = $app->input->getCmd('view', '');
$layout   = $app->input->getCmd('layout', '');
$task     = $app->input->getCmd('task', '');
$itemid   = $app->input->getCmd('Itemid', '');
$sitename = htmlspecialchars($app->get('sitename'), ENT_QUOTES, 'UTF-8');
$menu     = $app->getMenu()->getActive();
$pageclass = $menu !== null ? $menu->getParams()->get('pageclass_sfx', '') : '';

//Get params from template styling
// Template colors
$mainColor = $this->params->get('mainColor');
$subColor = $this->params->get('subColor');

// Decide type of desktop navigation
$navclass = "navbar-expand-lg";
if ($this->params->get('switchnavigatie')) {
	$navclass = "hamburger";
}

// Decide type of desktop navigation
$logoclass = "navbar-brand";
if ($this->params->get('logostamp')) {
	$logoclass = "navbar-brand logostamp";
}

// Adjusting main content width
if ($this->countModules('sidebar')) {
    $contentspan = "col-md-8 col-lg-9";
} else {
    $contentspan = "col-md-12";
}

// Adjusting bottom width
if ($this->countModules('bottom-a') && $this->countModules('bottom-b')) {
    $bottomspan = "col-md-6";
} else {
    $bottomspan = "col-md-12";
}


// Get this template's path
$templatePath = 'templates/' . $this->template;

// Load our frameworks
JHtml::_('bootstrap.framework');
JHtml::_('jquery.framework');

//Register our web assets (Css/JS)
$wa->useStyle('template.j4scoutingtc4.mainstyles');
$wa->useScript('template.j4scoutingtc4.scripts');

//Set viewport
$this->setMetaData('viewport', 'width=device-width, initial-scale=1');


?>
<!DOCTYPE html>
<html lang="<?php echo $this->language; ?>" dir="<?php echo $this->direction; ?>">
<head>
	<jdoc:include type="metas" />
	<jdoc:include type="styles" />
	<jdoc:include type="scripts" />
    
</head>

<body class="<?php echo $mainColor; ?> <?php echo $subColor; ?>">
    
    <nav id="tc4-nav" class="navbar navbar-light fixed-top <?php echo $navclass; ?>">
	    		    
	    <div class="container-fluid ">			    	

			<div id="tc4-logo" class="navbar-brand mr-auto">			        
				<a class="<?php echo $logoclass; ?>" href="<?php echo JURI::base(); ?>">
					<?php if ($this->params->get('eigenlogogebruiken')) { ?>
						<img class="eigenlogo" src="<?php echo $this->params->get('eigenlogo'); ?>">
					<?php } else { ?>
						<img class="scoutinglogo" src="<?php echo JURI::base(); ?>/media/templates/site/<?php echo $this->template; ?>/images/snl-logo.svg"alt="">
					<?php };  ?>
				</a>
			</div>
			
			<div id="tc4-headermessage" class="flex-grow-1">
			<?php if ($this->params->get('switchheadermessage')) { 
			
				$meldingsurl	= $this->params->get('headertextlink');
				$link_url = JRoute::_("index.php?Itemid={$meldingsurl}");?>
					
					<a class="text-danger" href="<?php echo $link_url;?>"><?php echo $this->params->get('headertext'); ?></a>
					
			<?php };  ?>
			</div>

			<div id="tc4-buttons" class="">

				<?php if ($this->params->get('zoekengebruiken')) { 					
					$zoekurl	= $this->params->get('zoekpagina');
					$zoek_Url		=  JRoute::_("index.php?Itemid={$zoekurl}");?>	
					<a href="<?php echo $zoek_Url;?>" class="search"><i id="tc4-navbar-search-icon" class="fa fa-search fa-2x"></i></a> 		 
				<?php };  ?>
				
				<?php if ($this->params->get('telefoongebruiken')) { 	
					$phone		= $this->params->get('telefoonnummer');?>
					<a href="tel:<?php echo $phone; ?>" class="phone"><i id="tc4-navbar-phone-icon" class="fa fa-phone fa-2x"></i></a> 
				<?php };  ?>
				
				<?php if ($this->params->get('contactgebruiken')) { 					
					$contacturl	= $this->params->get('contactpagina');
					$contact_Url		=  JRoute::_("index.php?Itemid={$contacturl}");?>	
					<a href="<?php echo $contact_Url;?>" class="contact"><i id="tc4-navbar-contact-icon" class="fa fa-envelope fa-2x"></i></a> 		 
				<?php };  ?>
														
				<button class="navbar-toggler navbar-toggler-right" type="button" data-bs-toggle="collapse" data-bs-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">

					<i id="tc4-navbar-toggler-icon" class="fa fa-bars fa-2x"></i>
				</button>
		
			</div>
			
			<div class="tc4-menu collapse navbar-collapse" id="navbarSupportedContent">
            	<jdoc:include type="modules" name="navbar" style="none" />
          	</div>
                     
        </div>
    </nav>

    <div class="mainbody">
        <div class="content">	
           
            <div id="tc4-hero" class="container-fluid px-0">
                <div class="row no-gutters">
	                <div class="col">
						<?php if ($this->countModules( 'hero' )) { ?>
							<jdoc:include type="modules" name="hero" style="none" />
						<?php } else if ($this->params->get('switchslide')) { ?>
							<div class="defaultbanner laag" style="background-image:url(<?php echo $this->params->get('eigenslide'); ?>)"></div>
						<?php } else { ?>
							<div class="defaultbanner laag" style="background-image:url(<?php echo JURI::base().'/media/templates/site/'.$this->template; ?>/images/default-slide.jpg)"></div>								
						<?php };  ?>
	                </div>
                </div>
            </div>

            <div class="container<?php echo ($this->params->get('fluidContainer') ? '-fluid' : ''); ?>">

				<?php if ($this->countModules('featured-a', true) || $this->countModules('featured-b', true) || $this->countModules('featured-c', true)) : ?>
                    <div id="tc4-featured" class="row">
                        <div class="col-sm-4">
                            <jdoc:include type="modules" name="featured-a" style="noCard" />
                        </div>
                        <div class="col-sm-4">
                            <jdoc:include type="modules" name="featured-b" style="noCard" />
                        </div>
                        <div class="col-sm-4">
                            <jdoc:include type="modules" name="featured-c" style="noCard" />
                        </div>
                    </div>
                <?php endif; ?>
                
            </div>

            <?php if ($this->countModules('showcase')) : ?>
                <div id="tc4-showcase" class="container-fluid px-0 text-light bg-success">
                    <div class="showcase-skyline">
	                    <div class="mover-1"></div>
	                    <div class="mover-2"></div>
                    </div> 
	                <div class="container">
                            <jdoc:include type="modules" name="showcase" style="none" />
                    </div>
                </div>
            <?php endif; ?>

			<div class="container<?php echo ($this->params->get('fluidContainer') ? '-fluid' : ''); ?>">

                <?php if ($this->countModules('news')) : ?>
                    <div id="tc4-news" class="row">
                        <div class="col-sm-12">
                            <jdoc:include type="modules" name="news" style="noCard" />
                        </div>
                    </div>
                    
                <?php endif; ?>
               
                <?php if ($this->countModules('breadcrumbs')) : ?>
                    <div id="tc4-breadcrumbs" class="row">
                        <div class="col-sm-12">
                            <jdoc:include type="modules" name="breadcrumbs" style="noCard" />
                        </div>
                    </div>
                <?php endif; ?>
                
                <div id="tc4-maincontent" class="row">
                    <main id="content" role="main" class="<?php echo $contentspan; ?>">
                        <jdoc:include type="message" />
                        <jdoc:include type="component" />
                    </main>
                    <?php if ($this->countModules('sidebar')) : ?>
                        <div id="aside" class="col-md-4 col-lg-3">
                            <jdoc:include type="modules" name="sidebar" style="noCard" />
                        </div>
                    <?php endif; ?>
                </div>


                 <?php if ($this->countModules('bottom-a', true) || $this->countModules('bottom-b', true)) : ?>
                 	<?php if ($this->params->get('lijnboven')) : ?>
				 		<div id="tc4-divider"></div>
				 	<?php endif; ?>
                    <div id="tc4-bottom" class="row">
                        <div class="<?php echo $bottomspan; ?> bottom-a">
                            <jdoc:include type="modules" name="bottom-a" style="noCard" />
                        </div>
                        <div class="<?php echo $bottomspan; ?> bottom-b">
                            <jdoc:include type="modules" name="bottom-b" style="noCard" />
                        </div>
                    </div>
                <?php endif; ?>
                
            </div>
        </div>
    </div>

    <!-- Load Footer -->
    <footer id="tc4-footer" class="text-light mt-5" role="contentinfo">
     
     	<div class="footer-grass"></div>
     	<div class="bg-success">   
            <div class="container<?php echo ($this->params->get('fluidContainer') ? '-fluid' : ''); ?>">
                <div class="row">
                    <div class="col-sm-6">
	                    <h3><?php echo JText::_('TPL_J4SCOUTINGTC4_FOOTER_TITLE'); ?></h3>
						<div class="social-icons">
							<?php $facebookurl=$this->params->get('facebookurl');
							if($facebookurl!= null) {?>	                    
								<a href="<?php echo $facebookurl; ?>"><i id="social-fb" class="fab fa-facebook fa-2x social"></i></a>
							<?php }?>
							<?php $twitterurl=$this->params->get('twitterurl');
							if($twitterurl!= null) {?>
								<a href="<?php echo $twitterurl; ?>"><i id="social-tw" class="fab fa-twitter fa-2x social"></i></a>
							<?php }?>							
							<?php $linkedinurl=$this->params->get('linkedinurl');
							if($linkedinurl!= null) {?>
			  				    <a href="<?php echo $linkedinurl; ?>"><i id="social-li" class="fab fa-linkedin fa-2x social"></i></a>
							<?php }?>		  				    
							<?php $youtubeurl=$this->params->get('youtubeurl');
							if($youtubeurl!= null) {?>
								<a href="<?php echo $youtubeurl; ?>"><i id="social-yt" class="fab fa-youtube fa-2x social"></i></a>
							<?php }?>						
							<?php $instagramurl=$this->params->get('instagramurl');
							if($instagramurl!= null) {?>
								<a href="<?php echo $instagramurl; ?>"><i id="social-ig" class="fab fa-instagram fa-2x social"></i></a>
							<?php }?>
						</div>					
						<div class="copyright">		                    
		                    <p>
	                            Copyright &copy; <?php echo date('Y'); ?> <?php echo $sitename; ?><br />
	                            <?php echo $this->params->get('copyrighttext'); ?>
	                        </p>
	                    </div>
                    </div>
                    <div class="col-sm-4">
                        <jdoc:include type="modules" name="footer" style="noCard" />
                    </div>                    
                </div>
            </div>
        </div>
    </footer>

    <!-- Include any debugging info -->
	<jdoc:include type="modules" name="debug" style="card" />
</body>
</html>
